EXPORTS
	??0CTmTextLayout@@QAE@XZ @ 1 NONAME ; public: __thiscall CTmTextLayout::CTmTextLayout(void)
	??0RTmParFormat@@QAE@XZ @ 2 NONAME ; public: __thiscall RTmParFormat::RTmParFormat(void)
	??0TTmBullet@@QAE@XZ @ 3 NONAME ; public: __thiscall TTmBullet::TTmBullet(void)
	??0TTmCharFormat@@QAE@ABVTDesC16@@H@Z @ 4 NONAME ; public: __thiscall TTmCharFormat::TTmCharFormat(class TDesC16 const &,int)
	??0TTmCharFormat@@QAE@XZ @ 5 NONAME ; public: __thiscall TTmCharFormat::TTmCharFormat(void)
	??0TTmCharFormatLayer@@QAE@ABVCCharFormatLayer@@@Z @ 6 NONAME ; public: __thiscall TTmCharFormatLayer::TTmCharFormatLayer(class CCharFormatLayer const &)
	??0TTmCharFormatMask@@QAE@ABVTCharFormatMask@@@Z @ 7 NONAME ; public: __thiscall TTmCharFormatMask::TTmCharFormatMask(class TCharFormatMask const &)
	??0TTmParBorder@@QAE@XZ @ 8 NONAME ; public: __thiscall TTmParBorder::TTmParBorder(void)
	??0TTmParFormatMask@@QAE@ABVTParaFormatMask@@@Z @ 9 NONAME ; public: __thiscall TTmParFormatMask::TTmParFormatMask(class TParaFormatMask const &)
	??1CTmText@@UAE@XZ @ 10 NONAME ; public: virtual __thiscall CTmText::~CTmText(void)
	??1CTmTextLayout@@UAE@XZ @ 11 NONAME ; public: virtual __thiscall CTmTextLayout::~CTmTextLayout(void)
	??4TTmBullet@@QAEXABVTBullet@@@Z @ 12 NONAME ; public: void __thiscall TTmBullet::operator=(class TBullet const &)
	??4TTmCharFormat@@QAEXABVTCharFormat@@@Z @ 13 NONAME ; public: void __thiscall TTmCharFormat::operator=(class TCharFormat const &)
	??4TTmParBorder@@QAEXABVTParaBorder@@@Z @ 14 NONAME ; public: void __thiscall TTmParBorder::operator=(class TParaBorder const &)
	??4TTmTab@@QAEXABVTTabStop@@@Z @ 15 NONAME ; public: void __thiscall TTmTab::operator=(class TTabStop const &)
	??8RTmParFormat@@QBEHABV0@@Z @ 16 NONAME ; public: int __thiscall RTmParFormat::operator==(class RTmParFormat const &)const 
	??8TTmBullet@@QBEHABV0@@Z @ 17 NONAME ; public: int __thiscall TTmBullet::operator==(class TTmBullet const &)const 
	??8TTmCharFormat@@QBEHABV0@@Z @ 18 NONAME ; public: int __thiscall TTmCharFormat::operator==(class TTmCharFormat const &)const 
	??8TTmParBorder@@QBEHABV0@@Z @ 19 NONAME ; public: int __thiscall TTmParBorder::operator==(class TTmParBorder const &)const 
	?AddParL@CTmTextLayout@@QAEHABVTTmFormatParamBase@@HAAH1@Z @ 20 NONAME ; public: int __thiscall CTmTextLayout::AddParL(class TTmFormatParamBase const &,int,int &,int &)
	?CancelLabelMode@MTmSource@@UAEXXZ @ 21 NONAME ; public: virtual void __thiscall MTmSource::CancelLabelMode(void)
	?ChangeFormatL@CTmText@@QAEXABVTTmFormatParamBase@@@Z @ 22 NONAME ; public: void __thiscall CTmText::ChangeFormatL(class TTmFormatParamBase const &)
	?Clear@CTmText@@QAEXXZ @ 23 NONAME ; public: void __thiscall CTmText::Clear(void)
	?Clear@CTmTextLayout@@QAEXXZ @ 24 NONAME ; public: void __thiscall CTmTextLayout::Clear(void)
	?Close@RTmParFormat@@QAEXXZ @ 25 NONAME ; public: void __thiscall RTmParFormat::Close(void)
	?CopyL@RTmParFormat@@QAEXABV1@@Z @ 26 NONAME ; public: void __thiscall RTmParFormat::CopyL(class RTmParFormat const &)
	?CopyL@RTmParFormat@@QAEXABVCParaFormat@@@Z @ 27 NONAME ; public: void __thiscall RTmParFormat::CopyL(class CParaFormat const &)
	?CopyL@RTmParFormatLayer@@QAEXABVCParaFormatLayer@@@Z @ 28 NONAME ; public: void __thiscall RTmParFormatLayer::CopyL(class CParaFormatLayer const &)
	?CopyL@RTmStyle@@QAEXABVRParagraphStyleInfo@@@Z @ 29 NONAME ; public: void __thiscall RTmStyle::CopyL(class RParagraphStyleInfo const &)
	?CustomizeL@CTmText@@QAEXPBVMTmCustom@@@Z @ 30 NONAME ; public: void __thiscall CTmText::CustomizeL(class MTmCustom const *)
	?DeletePar@CTmTextLayout@@QAEHABVTTmFormatParamBase@@HHAAH@Z @ 31 NONAME ; public: int __thiscall CTmTextLayout::DeletePar(class TTmFormatParamBase const &,int,int,int &)
	?DocPosToLine@CTmTextLayout@@QBEHABVTTmDocPos@@AAVTTmLineInfo@@@Z @ 32 NONAME ; public: int __thiscall CTmTextLayout::DocPosToLine(class TTmDocPos const &,class TTmLineInfo &)const 
	?DocPosToLine@MTmTextLayoutForwarder@@QBEHABVTTmDocPos@@AAVTTmLineInfo@@@Z @ 33 NONAME ; public: int __thiscall MTmTextLayoutForwarder::DocPosToLine(class TTmDocPos const &,class TTmLineInfo &)const 
	?DrawBackground@CTmTextLayout@@QBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@ABVTLogicalRgb@@@Z @ 34 NONAME ; public: void __thiscall CTmTextLayout::DrawBackground(class CGraphicsContext &,class TPoint const &,class TRect const &,class TLogicalRgb const &)const 
	?DrawBackground@MTmCustom@@UBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@ABVTLogicalRgb@@AAV4@@Z @ 35 NONAME ; public: virtual void __thiscall MTmCustom::DrawBackground(class CGraphicsContext &,class TPoint const &,class TRect const &,class TLogicalRgb const &,class TRect &)const 
	?DrawBackground@MTmTextLayoutForwarder@@QBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@ABVTLogicalRgb@@@Z @ 36 NONAME ; public: void __thiscall MTmTextLayoutForwarder::DrawBackground(class CGraphicsContext &,class TPoint const &,class TRect const &,class TLogicalRgb const &)const 
	?DrawLayout@CTmTextLayout@@QBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@PBVTLogicalRgb@@H@Z @ 37 NONAME ; public: void __thiscall CTmTextLayout::DrawLayout(class CGraphicsContext &,class TPoint const &,class TRect const &,class TLogicalRgb const *,int)const 
	?DrawLayout@MTmTextLayoutForwarder@@QBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@PBVTLogicalRgb@@H@Z @ 38 NONAME ; public: void __thiscall MTmTextLayoutForwarder::DrawLayout(class CGraphicsContext &,class TPoint const &,class TRect const &,class TLogicalRgb const *,int)const 
	?DrawLineGraphics@MTmCustom@@UBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@ABVTTmLineInfo@@@Z @ 39 NONAME ; public: virtual void __thiscall MTmCustom::DrawLineGraphics(class CGraphicsContext &,class TPoint const &,class TRect const &,class TTmLineInfo const &)const 
	?DrawText@MTmCustom@@UBEXAAVCGraphicsContext@@ABVTPoint@@ABVTRect@@ABVTTmLineInfo@@ABVTTmCharFormat@@ABVTDesC16@@1H@Z @ 40 NONAME ; public: virtual void __thiscall MTmCustom::DrawText(class CGraphicsContext &,class TPoint const &,class TRect const &,class TTmLineInfo const &,class TTmCharFormat const &,class TDesC16 const &,class TPoint const &,int)const 
	?EntryPoint@@YAHPAX@Z @ 41 NONAME ; int __cdecl EntryPoint(void *)
	?FindDocPos@CTmTextLayout@@QBEHABVTTmDocPos@@AAVTTmPosInfo@@AAVTTmLineInfo@@@Z @ 42 NONAME ; public: int __thiscall CTmTextLayout::FindDocPos(class TTmDocPos const &,class TTmPosInfo &,class TTmLineInfo &)const 
	?FindDocPos@MTmTextLayoutForwarder@@QBEHABVTTmDocPos@@AAVTTmPosInfo@@AAVTTmLineInfo@@@Z @ 43 NONAME ; public: int __thiscall MTmTextLayoutForwarder::FindDocPos(class TTmDocPos const &,class TTmPosInfo &,class TTmLineInfo &)const 
	?FindXyPos@CTmTextLayout@@QBEHABVTPoint@@AAVTTmPosInfo@@AAVTTmLineInfo@@@Z @ 44 NONAME ; public: int __thiscall CTmTextLayout::FindXyPos(class TPoint const &,class TTmPosInfo &,class TTmLineInfo &)const 
	?FindXyPos@MTmTextLayoutForwarder@@QBEHABVTPoint@@AAVTTmPosInfo@@AAVTTmLineInfo@@@Z @ 45 NONAME ; public: int __thiscall MTmTextLayoutForwarder::FindXyPos(class TPoint const &,class TTmPosInfo &,class TTmLineInfo &)const 
	?FormatL@CTmTextLayout@@QAEXABVTTmFormatParamBase@@ABVTTmReformatParam@@AAVTTmReformatResult@@@Z @ 46 NONAME ; public: void __thiscall CTmTextLayout::FormatL(class TTmFormatParamBase const &,class TTmReformatParam const &,class TTmReformatResult &)
	?GetCParaFormatL@RTmParFormat@@QBEXAAVCParaFormat@@@Z @ 47 NONAME ; public: void __thiscall RTmParFormat::GetCParaFormatL(class CParaFormat &)const 
	?GetCursor@CTmTextLayout@@QBEHABVTTmDocPos@@W4TTmCursorPlacement@@AAVTTmLineInfo@@AAVTPoint@@AAH44@Z @ 48 NONAME ; public: int __thiscall CTmTextLayout::GetCursor(class TTmDocPos const &,enum TTmCursorPlacement,class TTmLineInfo &,class TPoint &,int &,int &,int &)const 
	?GetCursor@MTmTextLayoutForwarder@@QBEHABVTTmDocPos@@W4TTmCursorPlacement@@AAVTTmLineInfo@@AAVTPoint@@AAH44@Z @ 49 NONAME ; public: int __thiscall MTmTextLayoutForwarder::GetCursor(class TTmDocPos const &,enum TTmCursorPlacement,class TTmLineInfo &,class TPoint &,int &,int &,int &)const 
	?GetDisplayedText@CTmTextLayout@@QBEHHAAVTDes16@@AAH@Z @ 50 NONAME ; public: int __thiscall CTmTextLayout::GetDisplayedText(int,class TDes16 &,int &)const 
	?GetFormat@CTmText@@QBEXAAVTTmFormatParamBase@@@Z @ 51 NONAME ; public: void __thiscall CTmText::GetFormat(class TTmFormatParamBase &)const 
	?GetLabelMetrics@MTmSource@@UBEXW4TLabelType@1@AAVTSize@@AAH@Z @ 52 NONAME ; public: virtual void __thiscall MTmSource::GetLabelMetrics(enum MTmSource::TLabelType,class TSize &,int &)const 
	?GetLineBreakInContext@MTmCustom@@UBEHABVTDesC16@@HHHAAH@Z @ 53 NONAME ; public: virtual int __thiscall MTmCustom::GetLineBreakInContext(class TDesC16 const &,int,int,int,int &)const 
	?GetLineBreakL@MTmSource@@QBEHABVTDesC16@@HHHHAAH11@Z @ 54 NONAME ; public: int __thiscall MTmSource::GetLineBreakL(class TDesC16 const &,int,int,int,int,int &,int &,int &)const 
	?GetMinimumLayoutSizeL@CTmTextLayout@@QBEXHAAVTSize@@@Z @ 55 NONAME ; public: void __thiscall CTmTextLayout::GetMinimumLayoutSizeL(int,class TSize &)const 
	?GetNextVisualCursorPos@CTmTextLayout@@QBEHABVTTmDocPos@@AAVTTmPosInfo@@H@Z @ 56 NONAME ; public: int __thiscall CTmTextLayout::GetNextVisualCursorPos(class TTmDocPos const &,class TTmPosInfo &,int)const 
	?GetNextVisualCursorPos@MTmTextLayoutForwarder@@QBEHABVTTmDocPos@@AAVTTmPosInfo@@H@Z @ 57 NONAME ; public: int __thiscall MTmTextLayoutForwarder::GetNextVisualCursorPos(class TTmDocPos const &,class TTmPosInfo &,int)const 
	?GetPictureSizeInTwipsL@MTmSource@@UBEHHAAVTSize@@@Z @ 58 NONAME ; public: virtual int __thiscall MTmSource::GetPictureSizeInTwipsL(int,class TSize &)const 
	?GetRParagraphStyleInfoL@RTmStyle@@QBEXAAVRParagraphStyleInfo@@ABVCParaFormatLayer@@ABVCCharFormatLayer@@ABVCStyleList@@@Z @ 59 NONAME ; public: void __thiscall RTmStyle::GetRParagraphStyleInfoL(class RParagraphStyleInfo &,class CParaFormatLayer const &,class CCharFormatLayer const &,class CStyleList const &)const 
	?GetStandardLineBreak@MTmSource@@SAXABVTDesC16@@HHAAH1@Z @ 60 NONAME ; public: static void __cdecl MTmSource::GetStandardLineBreak(class TDesC16 const &,int,int,int &,int &)
	?GetTBullet@TTmBullet@@QBEXAAVTBullet@@@Z @ 61 NONAME ; public: void __thiscall TTmBullet::GetTBullet(class TBullet &)const 
	?GetTCharFormat@TTmCharFormat@@QBEXAAVTCharFormat@@@Z @ 62 NONAME ; public: void __thiscall TTmCharFormat::GetTCharFormat(class TCharFormat &)const 
	?GetTCharFormatMask@TTmCharFormatMask@@QBEXAAVTCharFormatMask@@@Z @ 63 NONAME ; public: void __thiscall TTmCharFormatMask::GetTCharFormatMask(class TCharFormatMask &)const 
	?GetTParaBorder@TTmParBorder@@QBEXAAVTParaBorder@@@Z @ 64 NONAME ; public: void __thiscall TTmParBorder::GetTParaBorder(class TParaBorder &)const 
	?GetTParaFormatMask@TTmParFormatMask@@QBEXAAVTParaFormatMask@@@Z @ 65 NONAME ; public: void __thiscall TTmParFormatMask::GetTParaFormatMask(class TParaFormatMask &)const 
	?GetTTabStop@TTmTab@@QBEXAAVTTabStop@@@Z @ 66 NONAME ; public: void __thiscall TTmTab::GetTTabStop(class TTabStop &)const 
	?GetText@MUnifiedEditor@@QBEXHAAVTDes16@@@Z @ 67 NONAME ; public: void __thiscall MUnifiedEditor::GetText(int,class TDes16 &)const 
	?InsertL@CTmText@@QAEXHABVTDesC16@@PBVTTmCharFormat@@PBVRTmParFormat@@PAVTRect@@PAH@Z @ 68 NONAME ; public: void __thiscall CTmText::InsertL(int,class TDesC16 const &,class TTmCharFormat const *,class RTmParFormat const *,class TRect *,int *)
	?InvertLayout@CTmTextLayout@@QBEXAAVCGraphicsContext@@ABVTPoint@@HH@Z @ 69 NONAME ; public: void __thiscall CTmTextLayout::InvertLayout(class CGraphicsContext &,class TPoint const &,int,int)const 
	?InvertLayout@MTmTextLayoutForwarder@@QAEXAAVCGraphicsContext@@ABVTPoint@@HH@Z @ 70 NONAME ; public: void __thiscall MTmTextLayoutForwarder::InvertLayout(class CGraphicsContext &,class TPoint const &,int,int)
	?IsHangingCharacter@MTmCustom@@UBEHI@Z @ 71 NONAME ; public: virtual int __thiscall MTmCustom::IsHangingCharacter(unsigned int)const 
	?LineBreakClass@MTmCustom@@UBEIIAAI0@Z @ 72 NONAME ; public: virtual unsigned int __thiscall MTmCustom::LineBreakClass(unsigned int,unsigned int &,unsigned int &)const 
	?LineBreakPossible@MTmCustom@@UBEHIIH@Z @ 73 NONAME ; public: virtual int __thiscall MTmCustom::LineBreakPossible(unsigned int,unsigned int,int)const 
	?LineNumberToLine@CTmTextLayout@@QBEHHAAVTTmLineInfo@@@Z @ 74 NONAME ; public: int __thiscall CTmTextLayout::LineNumberToLine(int,class TTmLineInfo &)const 
	?LineNumberToLine@MTmTextLayoutForwarder@@QBEHHAAVTTmLineInfo@@@Z @ 75 NONAME ; public: int __thiscall MTmTextLayoutForwarder::LineNumberToLine(int,class TTmLineInfo &)const 
	?Lines@CTmTextLayout@@QBEHXZ @ 76 NONAME ; public: int __thiscall CTmTextLayout::Lines(void)const 
	?Map@MTmCustom@@UBEII@Z @ 77 NONAME ; public: virtual unsigned int __thiscall MTmCustom::Map(unsigned int)const 
	?MemoryUsed@CTmText@@QBEHXZ @ 78 NONAME ; public: int __thiscall CTmText::MemoryUsed(void)const 
	?MemoryUsed@CTmTextLayout@@QBEHXZ @ 79 NONAME ; public: int __thiscall CTmTextLayout::MemoryUsed(void)const 
	?NewL@CTmText@@SAPAV1@AAVMGraphicsDeviceMap@@ABVTTmFormatParamBase@@@Z @ 80 NONAME ; public: static class CTmText * __cdecl CTmText::NewL(class MGraphicsDeviceMap &,class TTmFormatParamBase const &)
	?NewL@CTmText@@SAPAV1@AAVMGraphicsDeviceMap@@HH@Z @ 81 NONAME ; public: static class CTmText * __cdecl CTmText::NewL(class MGraphicsDeviceMap &,int,int)
	?PageBreakInRange@MTmSource@@UBEHHH@Z @ 82 NONAME ; public: virtual int __thiscall MTmSource::PageBreakInRange(int,int)const 
	?ParNumberToLine@CTmTextLayout@@QBEHHHAAVTTmLineInfo@@@Z @ 83 NONAME ; public: int __thiscall CTmTextLayout::ParNumberToLine(int,int,class TTmLineInfo &)const 
	?ParNumberToLine@MTmTextLayoutForwarder@@QBEHHHAAVTTmLineInfo@@@Z @ 84 NONAME ; public: int __thiscall MTmTextLayoutForwarder::ParNumberToLine(int,int,class TTmLineInfo &)const 
	?ParagraphEnd@MTmSource@@QBEHH@Z @ 85 NONAME ; public: int __thiscall MTmSource::ParagraphEnd(int)const 
	?Paragraphs@CTmTextLayout@@QBEHXZ @ 86 NONAME ; public: int __thiscall CTmTextLayout::Paragraphs(void)const 
	?PictureL@MTmSource@@UBEPAVCPicture@@H@Z @ 87 NONAME ; public: virtual class CPicture * __thiscall MTmSource::PictureL(int)const 
	?SelectLabelMode@MTmSource@@UAEHW4TLabelType@1@H@Z @ 88 NONAME ; public: virtual int __thiscall MTmSource::SelectLabelMode(enum MTmSource::TLabelType,int)
	?SetBrushColor@MTmCustom@@QBEXAAVCGraphicsContext@@VTLogicalRgb@@@Z @ 89 NONAME ; public: void __thiscall MTmCustom::SetBrushColor(class CGraphicsContext &,class TLogicalRgb)const 
	?SetLineHeight@MTmCustom@@UBEXABVTLineHeightParam@1@AAH1@Z @ 90 NONAME ; public: virtual void __thiscall MTmCustom::SetLineHeight(class MTmCustom::TLineHeightParam const &,int &,int &)const 
	?SetPenColor@MTmCustom@@QBEXAAVCGraphicsContext@@VTLogicalRgb@@@Z @ 91 NONAME ; public: void __thiscall MTmCustom::SetPenColor(class CGraphicsContext &,class TLogicalRgb)const 
	?SetTextL@CTmTextLayout@@QAEXAAVMTmSource@@ABVTTmFormatParam@@@Z @ 92 NONAME ; public: void __thiscall CTmTextLayout::SetTextL(class MTmSource &,class TTmFormatParam const &)
	?SetWrapWidthL@CTmText@@QAEXH@Z @ 93 NONAME ; public: void __thiscall CTmText::SetWrapWidthL(int)
	?Spare1@CTmText@@AAEXXZ @ 94 NONAME ; private: void __thiscall CTmText::Spare1(void)
	?Stretch@MTmCustom@@UBEHI@Z @ 95 NONAME ; public: virtual int __thiscall MTmCustom::Stretch(unsigned int)const 
	?SystemColor@MTmCustom@@UBE?AVTRgb@@IV2@@Z @ 96 NONAME ; public: virtual class TRgb  __thiscall MTmCustom::SystemColor(unsigned int,class TRgb)const 
	?WidthOfWidestLine@CTmTextLayout@@QBEHHH@Z @ 97 NONAME ; public: int __thiscall CTmTextLayout::WidthOfWidestLine(int,int)const 
	?WidthOfWidestLine@MTmTextLayoutForwarder@@QBEHHH@Z @ 98 NONAME ; public: int __thiscall MTmTextLayoutForwarder::WidthOfWidestLine(int,int)const 
	?YPosToLine@CTmTextLayout@@QBEHHAAVTTmLineInfo@@@Z @ 99 NONAME ; public: int __thiscall CTmTextLayout::YPosToLine(int,class TTmLineInfo &)const 
	?YPosToLine@MTmTextLayoutForwarder@@QBEHHAAVTTmLineInfo@@@Z @ 100 NONAME ; public: int __thiscall MTmTextLayoutForwarder::YPosToLine(int,class TTmLineInfo &)const 

